@@ -166,10 +166,10 @@ mi.menu <- sidebarMenu(id = "principal",
 
 #Importa css y js. Tambien se decide el icono
 mi.head <- tags$head(
-  tags$link(rel = "stylesheet", type = "text/css", href = "style_promidat.css"),
+  tags$link(rel = "stylesheet", type = "text/css", href = "style_predictor.css"),
   tags$link(rel="icon", href="http://www.promidat.org/theme/image.php/formal_white/theme/1438713216/favicon"),
   useShinyjs(),
-  tags$script(src = "myscript.js"))
+  tags$script(src = "script_predictor.js"))
 
 #La  pagina de carga
 load.page <- conditionalPanel(condition="($('html').hasClass('shiny-busy'))",
@@ -1240,7 +1240,7 @@ pagina.info <- tabItem(tabName = "acercaDe",
                        infoBoxPROMiDAT(labelInput("copyright"), "PROMiDAT S.A.", icono = icon("copyright")),
                        infoBoxPROMiDAT(labelInput("info"), tags$a( href="https://www.promidat.com/", style = "color:white;",
                                                                    target = "_blank", "https://www.promidat.com"), icono = icon("info")),
-                       infoBoxPROMiDAT(labelInput("version"), "1.0.9", icono = icon("file-code-o")))
+                       infoBoxPROMiDAT(labelInput("version"), "1.1.0", icono = icon("file-code-o")))
 
 # PAGINA COMPLETA ---------------------------------------------------------------------------------------------------------
 
